netapp_ontap.models.storage_unit_encryption API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_unit_encryption`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageUnitEncryptionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageUnitEncryption object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `state: str GET`

    Storage unit data encryption state.
    unencrypted ‐ Unencrypted.
    software_encrypted ‐ Software encryption enabled.
    software_conversion_queued ‐ Queued for software conversion.
    software_encrypting ‐ Software encryption is in progress.
    software_rekeying ‐ Encryption with a new key is in progress.
    software_conversion_paused ‐ Software conversion is paused.
    software_rekey_paused ‐ Encryption with a new key is paused.
    software_rekey_queued ‐ Queued for software rekey.

    Valid choices:

    - unencrypted
    - software_encrypted
    - software_conversion_queued
    - software_encrypting
    - software_rekeying
    - software_conversion_paused
    - software_rekey_paused
    - software_rekey_queued